@@ -120,33 +120,54 @@ check_rprofile_update_packages <- function(files = NULL, all = FALSE,
 }
 
 
-check_options <- function(debug = FALSE) {
+check_options <- function(include = c("encoding", "error", "stringsAsFactors"), exclude = NA) {
+  include <- match.arg(include, several.ok = TRUE,
+                       choices = c("encoding", "error", "stringsAsFactors"))
+  if (length(include) == 0L) return()
+  if (length(exclude) > 0L) {
+    if (is.na(exclude)) {
+      ignore <- Sys.getenv("R_STARTUP_CHECK_OPTIONS_IGNORE", "error")
+      if (is.na(ignore)) ignore <- NULL
+      exclude <- getOption("startup.check.options.ignore", ignore)
+    }
+    keep <- (match(include, table = exclude, nomatch = 0L) == 0L)
+    include <- include[keep]
+  }
+  if (length(include) == 0L) return()
+
   msg <- function(opt, default, value, body = NULL) {
     msg <- sprintf("R option '%s' was changed (to '%s') during startup, cf. Startup.  Values other than the default '%s' is known to cause problems.", opt, value, default)
     msg <- c(msg, body)
     msg <- c(msg, sprintf("To disable this check, add \"%s\" to option 'startup.check.options.ignore'.", opt))
     paste("startup::check():", paste(msg, collapse = " "))
   }
-     
-  ignore <- getOption("startup.check.options.ignore")
 
-  opt <- "encoding"
-  default <- "native.enc"
-  if (!is.element(opt, ignore) && !interactive() &&
-      (value <- getOption(opt, default)) != default) {
-    warning(msg(opt, default, value, body = "For example, in non-interactive sessions installation of packages with non-ASCII characters (also in source code comments) fails. To set the encoding only in interactive mode, e.g. if (base::interactive()) options(encoding = \"UTF-8\")."), call. = FALSE)
-  }
-
-  opt <- "stringsAsFactors"
-  default <- TRUE
-  if (!is.element(opt, ignore) &&
-      (value <- getOption(opt, default)) != default) {
-    warning(msg(opt, default, value), call. = FALSE)
+  for (opt in include) {
+    if (opt == "encoding") {
+      value <- getOption(opt, default)
+      default <- "native.enc"
+      if (!interactive() && value != default) {
+        warning(msg(opt, default, value, body = "For example, in non-interactive sessions installation of packages with non-ASCII characters (also in source code comments) fails. To set the encoding only in interactive mode, e.g. if (base::interactive()) options(encoding = \"UTF-8\")."), call. = FALSE)
+      }
+    } else if (opt == "error") {
+      check_rstudio_option_error_conflict()
+    } else if (opt == "stringsAsFactors") {
+      value <- getOption(opt, default)
+      default <- if (getRversion() >= "4.0.0") FALSE else TRUE
+      if (value != default) {
+        warning(msg(opt, default, value), call. = FALSE)
+      }
+    }
   }
 }
 
 
-check_r_libs_env_vars <- function(debug = FALSE) {
+check_envs <- function() {
+  check_r_libs_env_vars()
+}
+
+
+check_r_libs_env_vars <- function() {
   vars <- c("R_LIBS", "R_LIBS_SITE", "R_LIBS_USER")
   for (var in vars) {
     path <- Sys.getenv(var)
@@ -204,9 +225,7 @@ check_r_libs_env_vars <- function(debug = FALSE) {
 }
 
 
-check_rstudio_option_error_conflict <- function(debug = FALSE) {
-  debug(debug)
-  debug <- debug(debug)
+check_rstudio_option_error_conflict <- function() {
   ## Nothing to do?
   if (is.null(getOption("error")) || !is_rstudio_console()) return()
 
@@ -244,5 +263,8 @@ check_rstudio_option_error_conflict <- function(debug = FALSE) {
     }
   }
 
-  warning("startup::check(): ", "CONFLICT: Option ", sQuote("error"), " was set during the R startup, but this will be overridden by the RStudio settings (menu ", sQuote("Debug -> On Error"), ") when using the RStudio Console. To silence this warning, set option 'error' using ", sQuote("if (!startup::sysinfo()$rstudio) options(error = ...)"), ". For further details on this issue, see https://github.com/rstudio/rstudio/issues/3007")
+  ## Record intended value of option 'error'
+  options(startup.error.lost = getOption("error"))
+
+  warning("startup::check(): ", "CONFLICT: Option ", sQuote("error"), " was set during the R startup, but this will be overridden due to the RStudio settings (menu ", sQuote("Debug -> On Error"), ") when using the RStudio Console. To silence this warning, do not set option 'error' when running RStudio Console, e.g. ", sQuote("if (!startup::sysinfo()$rstudio) options(error = ...)"), ". The 'error' option that was set during the startup process but lost is recorded in option ", sQuote("startup.error.lost"), ". For further details on this issue, see https://github.com/rstudio/rstudio/issues/3007")
 }
