@@ -17,8 +17,11 @@ sysinfo <- function() {
   sysinfo$ess <- is_ess()
   sysinfo$microsoftr <- is_microsoftr()
   sysinfo$pqr <- is_pqr()
-  sysinfo$rtichoke <- is_rtichoke()
-  sysinfo$rice <- sysinfo$rtichoke  ## Renamed February 2018
+  sysinfo$radian <- is_radian()
+  ## Deprecated: Renamed rtichoke -> radian in December 2018
+  sysinfo$rtichoke <- sysinfo$radian
+  ## Deprecated: Renamed rice -> rtichoke in February 2018
+  sysinfo$rice <- sysinfo$radian
   sysinfo$rstudio <- is_rstudio_console()
   sysinfo$rstudioterm <- is_rstudio_terminal()
   sysinfo$wine <- is_wine()
